import React, { Component } from 'react';
import { fromJS, Map, List, is } from 'immutable';
import { Popover, message } from 'antd';
import Button from '@/ant_components/BIButton';
import classnamse from 'classnames';
import SearchView from '@/submodule/components/SearchView';
import BISelect from '@/ant_components/BISelect';
import filterIcon from '@/assets/airTable/filter.png';
import closeIcon from '@/assets/airTable/close.png';
import SettingPanel from './hide'
import styles from './styles.less';

const TransType = ['2', '3', '4', '13', '14'];
/** 
 * 操作栏过滤条件控制
 * 参数
 * @filterValues        已有的过滤条件
 * @filterColumnConfig  可以过滤的配置项
 * @onChange            变化回调
 * @hideSettingPanel    设置过滤条件
 * @conditions          全量条件数据
 * @openSettingPanel     打开设置变量看板
 * @closeSettingPanel    关闭设置变量看板
 * @selectedConditions   已选择条件数据
 * 
 */
export default class Filter extends Component {
    constructor(props) {
        super(props);
        this.state = {
            visible: false,
            filterConfig: props.filterConfig || [{}],
        };
    }

    componentDidMount() {
        const { filterConfig = [] } = this.props;
        this.setState({
            filterConfig: filterConfig.length > 0 ? filterConfig : [{}],
        });
    }

    componentWillReceiveProps(nextProps) {
        const { filterConfig } = this.props;
        const x1 = fromJS(filterConfig);
        const x2 = fromJS(nextProps.filterConfig);
        if (!is(x1, x2)) {
            this.setState({
                filterConfig: nextProps.filterConfig.length > 0 ? nextProps.filterConfig : [{}],
            });
        }
    }

    toggleOption = () => {
        const { visible } = this.state;
        this.setState({
            visible: !visible,
        });
    };

    // 重置
    resetFilterItem = () => {
        this.setState({
            filterConfig: [{}],
        });
        this.onChange([]);
    };
    // 改变筛选条件
    changeFilterKey = (index, value) => {
        const { filterConfig } = this.state;
        const { filterColumnConfig } = this.props;
        const filter = filterColumnConfig.find((item) => {
            return item.key === value;
        });
        const data = {
            colName: value,
            colChsName: filter.title,
            operationCode: filter.operator && filter.operator[0] && filter.operator[0].id,
            colValues: undefined,
        };
        const temp = List(filterConfig)
            .splice(index, 1, data)
            .toJS();
        this.setState({
            filterConfig: temp,
        });
    };

    // 回调表格更改操作栏方法
    onChange = (props, changedValues, allValues) => {
        // const { onChange, filterConfig } = this.props;
        // const x1 = fromJS(changedConfig);
        // const x2 = fromJS(filterConfig);
        // if (!is(x1, x2)) {
        //     if (typeof onChange === 'function') {
        //         onChange({ type: 'filterConfig', config: changedConfig });
        //     }
        // }
    };
    // 渲染搜索栏
    _renderSearchForm = () => {
        const { selectedConditions = [] } = this.props;
        const { searchForm = {} } = this.state;
        if (selectedConditions === null || selectedConditions.length <= 0) return null;
        return (
            <SearchView
                modal='modal'
                searchForm={searchForm}
                searchCols={selectedConditions}
                search={this.search}
                onChangeParams={this.onChange}
            />
        );
    };
    renderContent = () => {
        const { hideSettingPanel } = this.props;
        return (
            <div className={styles.optionsModal}>
                <div className={styles.content}>
                    {this._renderSearchForm()}
                </div>
                <div className={styles.btns}>

                    <div role="presentation" className={styles.addFilterBtn}>
                        {hideSettingPanel ? null : <SettingPanel {...this.props} />}
                    </div>
                    <div className={styles.handleBtn}>
                        <Button
                            className={classnamse(styles.btn, styles.resetBtn)}
                        >
                            重置
                        </Button>
                        <Button
                            className={classnamse(styles.btn, styles.okBtn)}

                            type="primary"
                        >
                            确认
                        </Button>
                    </div>
                </div>
            </div>
        );
    };
    renderOpenBtn = () => {
        const { filterValues = [] } = this.props;
        if (this.props.renderOpenBtn && typeof this.props.renderOpenBtn === 'function') {
            return this.props.renderOpenBtn();
        }
        // const len = filterValues.filter((item) => {
        //     return item.value > 0;
        // }).length;
        const len = 10
        let background = len > 0 ? 'rgba(247,181,0,0.1)' : '';
        return (
            <div className={styles.operateContainer} style={{ background }}>
                <img alt="" className={styles.operateIcon} src={filterIcon} />
                <span className={styles.operateName}>{len > 0 ? `${len}条筛选` : '筛选'}</span>
            </div>
        )
    }

    render() {
        return (
            <Popover
                overlayClassName={styles.popover}
                placement="bottomLeft"
                title="筛选条件"
                content={this.renderContent()}
                visible={true}
                onVisibleChange={this.toggleOption}
                trigger="click"
            >
                {this.renderOpenBtn()}
            </Popover>
        );
    }
}